
#Multiple linear regression and random forest models for prediction of salt concentrations in Antarctic soils
#The training datasets are published by Diaz et al. (2020): 
#"Geochemical zones and environmental gradients for soils from the Central Transantarctic Mountains#
#doi: __________________
#Please cite Diaz et al. (2020) for use of the datasets and models

#Loading all required packages
library(ggplot2)
library(randomForest)
library(e1071)
library(caret)
library(smatr)

#Import the training datasets for the multiple linear regression and random forest models
Salts <- read_excel("~/Downloads/Salts.xlsx")
RFSalts_Train <- read_excel("~/Downloads/RFSalts_Train.xlsx")
RFSalts_Test <-read_excel("~/Downloads/RFSalts_Test.xlsx")
Darwin <- read_excel("~/Downloads/Darwin_Test.xlsx")

###########################################################################################################################
#Creating the multiple linear regression models using the Salts dataset

#For Total salts
#Creating the linear model with the 5 geographic parameters + soil moisture
TSreg <- lm(data = RFSalts_Train, Total_salt~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture)
#Printing model statistics to evaluate model strength
summary(TSreg)

#For N:P ratio
NPreg <- lm(data = RFSalts_Train, NP~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture)
summary(NPreg)

#For ClO4
ClO4reg <- lm(data = Salts, ClO4~ Latitude + Longitude + Elevation + Distance_from_coast + 
                Distance_from_glacier + Soil_moisture)
summary(ClO4reg)

#For Cl
Clreg <- lm(data = Salts, Cl~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture)
summary(Clreg)

#For F
Freg <- lm(data = Salts, F~ Latitude + Longitude + Elevation + Distance_from_coast + 
             Distance_from_glacier + Soil_moisture)
summary(Freg)

#For NO3
NO3reg <- lm(data = Salts, NO3~ Latitude + Longitude + Elevation + Distance_from_coast + 
               Distance_from_glacier + Soil_moisture)
summary(NO3reg)

#For SO4
SO4reg <- lm(data = Salts, SO4~ Latitude + Longitude + Elevation + Distance_from_coast + 
               Distance_from_glacier + Soil_moisture)
summary(SO4reg)

#For PO4
PO4reg <- lm(data = Salts, PO4~ Latitude + Longitude + Elevation + Distance_from_coast + 
               Distance_from_glacier + Soil_moisture)
summary(PO4reg)

#For Ca
Careg <- lm(data = Salts, Ca~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture)
summary(Careg)

#For Mg
Mgreg <- lm(data = Salts, Mg~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture)
summary(Mgreg)

#For Na
Nareg <- lm(data = Salts, Na~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture)
summary(Nareg)

#For K
Kreg <- lm(data = Salts, K~ Latitude + Longitude + Elevation + Distance_from_coast + 
             Distance_from_glacier + Soil_moisture)
summary(Kreg)

#For Sr
Srreg <- lm(data = Salts, Sr~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture)
summary(Srreg)

#For NH3
NH3reg <- lm(data = Salts, NH3~ Latitude + Longitude + Elevation + Distance_from_coast + 
               Distance_from_glacier + Soil_moisture)
summary(NH3reg)

###########################################################################################################################

#Creating the random forest model with the training dataset
#mtry is set as default, which in this case is n/3 = 2. This is the value with the minimum error

#For Total salts
#Building the random forest model
RFModelTS <- randomForest(Total_salt ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
#Seeing which variables were most and least important for nude purity
varImpPlot(RFModelTS)

#For N:P molar ratio
RFModelNP <- randomForest(NP ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelNP)

#For ClO4 
RFModelClO4 <- randomForest(ClO4 ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                              Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelClO4)

#For Cl
RFModelCl <- randomForest(Cl ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelCl)

#For F 
RFModelF <- randomForest(F ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                           Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelF)

#For NO3 
RFModelNO3 <- randomForest(NO3 ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                             Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelNO3)

#For SO4 
RFModelSO4 <- randomForest(SO4 ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                             Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelSO4)

#For PO4 
RFModelPO4 <- randomForest(PO4 ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                             Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelPO4)

#For Ca 
RFModelCa <- randomForest(Ca ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelCa)

#For Mg 
RFModelMg <- randomForest(Mg ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelMg)

#For Na 
RFModelNa <- randomForest(Na ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelNa)

#For K 
RFModelK <- randomForest(K ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                           Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelK)

#For Sr 
RFModelSr <- randomForest(Sr ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelSr)

#For NH3 
RFModelNH3 <- randomForest(NH3 ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                             Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelNH3)
###########################################################################################################################

#Running the Shackleton Glacier region test dataset on the generated multiple linear regression models

#For Total salts
#Inputting the new test dataset and storing the predicted concentration results
TSLMPred <- predict(TSreg, newdata = RFSalts_Test)
#Running a correlation between the measured and predicted values
cor.test(TSLMPred, RFSalts_Test$Total_salt)
#Quick visual check of the data
plot(TSLMPred, RFSalts_Test$Total_salt)
#Determining the slope by fitting bivariate lines using the standardized major axis (SMA) for measured and predicted values
#A slope of 1 is ideal, where there is a direct 1:1 relationship
#sma will test the slope estimate and determine the test statistic for the null hypothesis
sma(TSLMPred~ RFSalts_Test$Total_salt, slope.test=1)
#Determing the mean absolute error (MAE) and root mean squared error (RMSE)
mae(TSLMPred, RFSalts_Test$Total_salt)
rmse(TSLMPred, RFSalts_Test$Total_salt)

#For N:P ratio
NPLMPred <- predict(NPreg, newdata = RFSalts_Test)
cor.test(NPLMPred, RFSalts_Test$NP)
plot(NPLMPred, RFSalts_Test$NP)
sma(NPLMPred~ RFSalts_Test$NP, slope.test=1)
mae(NPLMPred, RFSalts_Test$NP)
rmse(NPLMPred, RFSalts_Test$NP)

#For ClO4
ClO4LMPred <- predict(ClO4reg, newdata = RFSalts_Test)
cor.test(ClO4LMPred, RFSalts_Test$ClO4)
plot(ClO4LMPred, RFSalts_Test$ClO4)
sma(ClO4LMPred~ RFSalts_Test$ClO4, slope.test=1)
mae(ClO4LMPred, RFSalts_Test$ClO4)
rmse(ClO4LMPred, RFSalts_Test$ClO4)

#For ClO3
ClO3LMPred <- predict(ClO3reg, newdata = RFSalts_Test)
cor.test(ClO3LMPred, RFSalts_Test$ClO3)
plot(ClO3LMPred, RFSalts_Test$ClO3)
sma(ClO3LMPred~ RFSalts_Test$ClO3, slope.test=1)
mae(ClO3LMPred, RFSalts_Test$ClO3)
rmse(ClO3LMPred, RFSalts_Test$ClO3)

#For Cl
ClLMPred <- predict(Clreg, newdata = RFSalts_Test)
cor.test(ClLMPred, RFSalts_Test$Cl)
plot(ClLMPred, RFSalts_Test$Cl)
sma(ClLMPred~ RFSalts_Test$Cl, slope.test=1)
mae(ClLMPred, RFSalts_Test$Cl)
rmse(ClLMPred, RFSalts_Test$Cl)

#For F
FLMPred <- predict(Freg, newdata = RFSalts_Test)
cor.test(FLMPred, RFSalts_Test$F)
plot(FLMPred, RFSalts_Test$F)
sma(FLMPred~ RFSalts_Test$F, slope.test=1)
mae(FLMPred, RFSalts_Test$F)
rmse(FLMPred, RFSalts_Test$F)

#For NO3
NO3LMPred <- predict(NO3reg, newdata = RFSalts_Test)
cor.test(NO3LMPred, RFSalts_Test$NO3)
plot(NO3LMPred, RFSalts_Test$NO3)
sma(NO3LMPred~ RFSalts_Test$NO3, slope.test=1)
mae(NO3LMPred, RFSalts_Test$NO3)
rmse(NO3LMPred, RFSalts_Test$NO3)

#For SO4
SO4LMPred <- predict(SO4reg, newdata = RFSalts_Test)
cor.test(SO4LMPred, RFSalts_Test$SO4)
plot(SO4LMPred, RFSalts_Test$SO4)
sma(SO4LMPred~ RFSalts_Test$SO4, slope.test=1)
mae(SO4LMPred, RFSalts_Test$SO4)
rmse(SO4LMPred, RFSalts_Test$SO4)

#For PO4
PO4LMPred <- predict(PO4reg, newdata = RFSalts_Test)
cor.test(PO4LMPred, RFSalts_Test$PO4)
plot(PO4LMPred, RFSalts_Test$PO4)
sma(PO4LMPred~ RFSalts_Test$PO4, slope.test=1)
mae(PO4LMPred, RFSalts_Test$PO4)
rmse(PO4LMPred, RFSalts_Test$PO4)

#For Ca
CaLMPred <- predict(Careg, newdata = RFSalts_Test)
cor.test(CaLMPred, RFSalts_Test$Ca)
sma(CaLMPred~ RFSalts_Test$Ca, slope.test=1)
mae(CaLMPred, RFSalts_Test$Ca)
rmse(CaLMPred, RFSalts_Test$Ca)

#For Mg
MgLMPred <- predict(Mgreg, newdata = RFSalts_Test)
cor.test(MgLMPred, RFSalts_Test$Mg)
plot(MgLMPred, RFSalts_Test$Mg)
sma(MgLMPred~ RFSalts_Test$Mg, slope.test=1)
mae(MgLMPred, RFSalts_Test$Mg)
rmse(MgLMPred, RFSalts_Test$Mg)

#For Na
NaLMPred <- predict(Nareg, newdata = RFSalts_Test)
cor.test(NaLMPred, RFSalts_Test$Na)
plot(NaLMPred, RFSalts_Test$Na)
sma(NaLMPred~ RFSalts_Test$Na, slope.test=1)
mae(NaLMPred, RFSalts_Test$Na)
rmse(NaLMPred, RFSalts_Test$Na)

#For K
KLMPred <- predict(Kreg, newdata = RFSalts_Test)
cor.test(KLMPred, RFSalts_Test$K)
plot(KLMPred, RFSalts_Test$K)
sma(KLMPred~ RFSalts_Test$K, slope.test=1)
mae(KLMPred, RFSalts_Test$K)
rmse(KLMPred, RFSalts_Test$K)

#For Sr
SrLMPred <- predict(Srreg, newdata = RFSalts_Test)
cor.test(SrLMPred, RFSalts_Test$Sr)
plot(SrLMPred, RFSalts_Test$Sr)
sma(SrLMPred~ RFSalts_Test$Sr, slope.test=1)
mae(SrLMPred, RFSalts_Test$Sr)
rmse(SrLMPred, RFSalts_Test$Sr)

#For NH3
NH3LMPred <- predict(NH3reg, newdata = RFSalts_Test)
cor.test(NH3LMPred, RFSalts_Test$NH3)
plot(NH3LMPred, RFSalts_Test$NH3)
sma(NH3LMPred~ RFSalts_Test$NH3, slope.test=1)
mae(NH3LMPred, RFSalts_Test$NH3)
rmse(NH3LMPred, RFSalts_Test$NH3)

###########################################################################################################################

#Running the Shackleton Glacier region test dataset on the generated random forest models

#For Total salts
#Inputting the new test dataset and storing the predicted concentration results
TSRFPred<- predict(RFModelTS, newdata = RFSalts_Test)
#Running a correlation between the measured and predicted values
cor.test(TSRFPred, RFSalts_Test$Total_salt)
#Quick visual check of the data
plot(TSRFPred, RFSalts_Test$Total_salt)
#Determining the slope by fitting bivariate lines using the standardized major axis (SMA) for measured and predicted values
#A slope of 1 is ideal, where there is a direct 1:1 relationship
#sma will test the slope estimate and determine the test statistic for the null hypothesis
sma(TSRFPred ~ RFSalts_Test$Total_salt, slope.test=1)
#Determing the mean absolute error (MAE) and root mean squared error (RMSE)
mae(TSRFPred, RFSalts_Test$Total_salt)
rmse(TSRFPred, RFSalts_Test$Total_salt)

#For N:P ratio
NPRFPred<- predict(RFModelNP, newdata = RFSalts_Test)
cor.test(NPRFPred, RFSalts_Test$NP)
plot(NPRFPred, RFSalts_Test$NP)
sma(NPRFPred ~ RFSalts_Test$NP, slope.test=1)
mae(NPRFPred, RFSalts_Test$NP)
rmse(NPRFPred, RFSalts_Test$NP)

#For ClO4
ClO4RFPred<- predict(RFModelClO4, newdata = RFSalts_Test)
cor.test(ClO4RFPred, RFSalts_Test$ClO4)
plot(ClO4RFPred, RFSalts_Test$ClO4)
sma(ClO4RFPred ~ RFSalts_Test$ClO4, slope.test=1)
mae(ClO4RFPred, RFSalts_Test$ClO4)
rmse(ClO4RFPred, RFSalts_Test$ClO4)

#For ClO3
ClO3RFPred<- predict(RFModelClO3, newdata = RFSalts_Test)
cor.test(ClO3RFPred, RFSalts_Test$ClO3)
plot(ClO3RFPred, RFSalts_Test$ClO3)
sma(ClO3RFPred ~ RFSalts_Test$ClO3, slope.test=1)
mae(ClO3RFPred, RFSalts_Test$ClO3)
rmse(ClO3RFPred, RFSalts_Test$ClO3)

#For Cl
ClRFPred<- predict(RFModelCl, newdata = RFSalts_Test)
cor.test(ClRFPred, RFSalts_Test$Cl)
plot(ClRFPred, RFSalts_Test$Cl)
sma(ClRFPred ~ RFSalts_Test$Cl, slope.test=1)
mae(ClRFPred, RFSalts_Test$Cl)
rmse(ClRFPred, RFSalts_Test$Cl)

#For K
KRFPred<- predict(RFModelK, newdata = RFSalts_Test)
cor.test(KRFPred, RFSalts_Test$K)
plot(KRFPred, RFSalts_Test$K)
sma(KRFPred ~ RFSalts_Test$K, slope.test=1)
mae(KRFPred, RFSalts_Test$K)
rmse(KRFPred, RFSalts_Test$K)

#For NO3
NO3RFPred<- predict(RFModelNO3, newdata = RFSalts_Test)
cor.test(NO3RFPred, RFSalts_Test$NO3)
sma(NO3RFPred ~ RFSalts_Test$NO3, slope.test=1)
mae(NO3RFPred, RFSalts_Test$NO3)
rmse(NO3RFPred, RFSalts_Test$NO3)

#For SO4
SO4RFPred<- predict(RFModelSO4, newdata = RFSalts_Test)
cor.test(SO4RFPred, RFSalts_Test$SO4)
plot(SO4RFPred, RFSalts_Test$SO4)
sma(SO4RFPred ~ RFSalts_Test$SO4, slope.test=1)
mae(SO4RFPred, RFSalts_Test$SO4)
rmse(SO4RFPred, RFSalts_Test$SO4)

#For PO4
PO4RFPred<- predict(RFModelPO4, newdata = RFSalts_Test)
cor.test(PO4RFPred, RFSalts_Test$PO4)
plot(PO4RFPred, RFSalts_Test$PO4)
sma(PO4RFPred ~ RFSalts_Test$PO4, slope.test=1)
mae(PO4RFPred, RFSalts_Test$PO4)
rmse(PO4RFPred, RFSalts_Test$PO4)

#For Ca
CaRFPred<- predict(RFModelCa, newdata = RFSalts_Test)
cor.test(CaRFPred, RFSalts_Test$Ca)
plot(CaRFPred, RFSalts_Test$Ca)
sma(CaRFPred ~ RFSalts_Test$Ca, slope.test=1)
mae(CaRFPred, RFSalts_Test$Ca)
rmse(CaRFPred, RFSalts_Test$Ca)

#For Mg
MgRFPred<- predict(RFModelMg, newdata = RFSalts_Test)
cor.test(MgRFPred, RFSalts_Test$Mg)
plot(MgRFPred, RFSalts_Test$Mg)
sma(MgRFPred ~ RFSalts_Test$Mg, slope.test=1)
mae(MgRFPred, RFSalts_Test$Mg)
rmse(MgRFPred, RFSalts_Test$Mg)

#For Na
NaRFPred<- predict(RFModelNa, newdata = RFSalts_Test)
cor.test(NaRFPred, RFSalts_Test$Na)
plot(NaRFPred, RFSalts_Test$Na)
sma(NaRFPred ~ RFSalts_Test$Na, slope.test=1)
mae(NaRFPred, RFSalts_Test$Na)
rmse(NaRFPred, RFSalts_Test$Na)

#For F
FRFPred<- predict(RFModelF, newdata = RFSalts_Test)
cor.test(FRFPred, RFSalts_Test$F)
plot(FRFPred, RFSalts_Test$F)
sma(FRFPred ~ RFSalts_Test$F, slope.test=1)
mae(FRFPred, RFSalts_Test$F)
rmse(FRFPred, RFSalts_Test$F)

#For Sr
SrRFPred<- predict(RFModelSr, newdata = RFSalts_Test)
cor.test(SrRFPred, RFSalts_Test$Sr)
plot(SrRFPred, RFSalts_Test$Sr)
sma(SrRFPred ~ RFSalts_Test$Sr, slope.test=1)
mae(SrRFPred, RFSalts_Test$Sr)
rmse(SrRFPred, RFSalts_Test$Sr)

#For NH3
NH3RFPred<- predict(RFModelNH3, newdata = RFSalts_Test)
cor.test(NH3RFPred, RFSalts_Test$NH3)
plot(NH3RFPred, RFSalts_Test$NH3)
sma(NH3RFPred ~ RFSalts_Test$NH3, slope.test=1)
mae(NH3RFPred, RFSalts_Test$NH3)
rmse(NH3RFPred, RFSalts_Test$NH3)

###########################################################################################################################

#Running the Darwin Glacier region test dataset on the generated multiple linear regression models

#For Total salts
#Inputting the new test dataset and storing the predicted concentration results
Darwin_TSLMPred <- predict(TSreg, newdata = Darwin)
#Running a correlation between the measured and predicted values
cor.test(Darwin_TSLMPred, Darwin$Total_salt)
#Quick visual check of the data
plot(Darwin_TSLMPred, Darwin$Total_salt)
#Determining the slope by fitting bivariate lines using the standardized major axis (SMA) for measured and predicted values
#A slope of 1 is ideal, where there is a direct 1:1 relationship
#sma will test the slope estimate and determine the test statistic for the null hypothesis
sma(Darwin_TSLMPred~ Darwin$Total_salt, slope.test=1)
#Determing the mean absolute error (MAE) and root mean squared error (RMSE)
mae(Darwin_TSLMPred, Darwin$Total_salt)
rmse(Darwin_TSLMPred, Darwin$Total_salt)

#For N:P ratio
Darwin_NPLMPred <- predict(NPreg, newdata = Darwin)
cor.test(Darwin_NPLMPred, Darwin$NP)
plot(Darwin_NPLMPred, Darwin$NP)
sma(Darwin_NPLMPred~ Darwin$NP, slope.test=1)
mae(Darwin_NPLMPred, Darwin$NP)
rmse(Darwin_NPLMPred, Darwin$NP)

#For Cl
Darwin_ClLMPred <- predict(Clreg, newdata = Darwin)
cor.test(Darwin_ClLMPred, Darwin$Cl)
plot(Darwin_ClLMPred, Darwin$Cl)
sma(Darwin_ClLMPred~ Darwin$Cl, slope.test=1)
mae(Darwin_ClLMPred, Darwin$Cl)
rmse(Darwin_ClLMPred, Darwin$Cl)

#For NO3
Darwin_NO3LMPred <- predict(NO3reg, newdata = Darwin)
cor.test(Darwin_NO3LMPred, Darwin$NO3)
plot(Darwin_NO3LMPred, Darwin$NO3)
sma(Darwin_NO3LMPred~ Darwin$NO3, slope.test=1)
mae(Darwin_NO3LMPred, Darwin$NO3)
rmse(Darwin_NO3LMPred, Darwin$NO3)

#For Ca
Darwin_CaLMPred <- predict(Careg, newdata = Darwin)
cor.test(Darwin_CaLMPred, Darwin$Ca)
plot(Darwin_CaLMPred, Darwin$Ca)
sma(Darwin_CaLMPred~ Darwin$Ca, slope.test=1)
mae(Darwin_CaLMPred, Darwin$Ca)
rmse(Darwin_CaLMPred, Darwin$Ca)

#For Mg
Darwin_MgLMPred <- predict(Mgreg, newdata = Darwin)
cor.test(Darwin_MgLMPred, Darwin$Mg)
plot(Darwin_MgLMPred, Darwin$Mg)
sma(Darwin_MgLMPred~ Darwin$Mg, slope.test=1)
mae(Darwin_MgLMPred, Darwin$Mg)
rmse(Darwin_MgLMPred, Darwin$Mg)

#For Na
Darwin_NaLMPred <- predict(Nareg, newdata = Darwin)
cor.test(Darwin_NaLMPred, Darwin$Na)
plot(Darwin_NaLMPred, Darwin$Na)
sma(Darwin_NaLMPred~ Darwin$Na, slope.test=1)
mae(Darwin_NaLMPred, Darwin$Na)
rmse(Darwin_NaLMPred, Darwin$Na)

#For K
Darwin_KLMPred <- predict(Kreg, newdata = Darwin)
cor.test(Darwin_KLMPred, Darwin$K)
plot(Darwin_KLMPred, Darwin$K)
sma(Darwin_KLMPred~ Darwin$K, slope.test=1)
mae(Darwin_KLMPred, Darwin$K)
rmse(Darwin_KLMPred, Darwin$K)

###########################################################################################################################

#Running the Darwin Glacier region test dataset on the generated random forest models

#For Total salts
#Inputting the new test dataset and storing the predicted concentration results
Darwin_TSRFPred<-predict(RFModelTS, newdata = Darwin)
#Running a correlation between the measured and predicted values
cor.test(Darwin_TSRFPred, Darwin$Total_salt)
#Quick visual check of the data
plot(Darwin_TSRFPred, Darwin$Total_salt)
#Determining the slope by fitting bivariate lines using the standardized major axis (SMA) for measured and predicted values
#A slope of 1 is ideal, where there is a direct 1:1 relationship
#sma will test the slope estimate and determine the test statistic for the null hypothesis
sma(Darwin_TSRFPred~ Darwin$Total_salt, slope.test=1)
#Determing the mean absolute error (MAE) and root mean squared error (RMSE)
mae(Darwin_TSRFPred, Darwin$Total_salt)
rmse(Darwin_TSRFPred, Darwin$Total_salt)

#For N:P ratio
Darwin_NPRFPred<-predict(RFModelNP, newdata = Darwin)
cor.test(Darwin_NPRFPred, Darwin$NP)
plot(Darwin_NPRFPred, Darwin$NP)
sma(Darwin_NPRFPred~ Darwin$NP, slope.test=1)
mae(Darwin_NPRFPred, Darwin$NP)
rmse(Darwin_NPRFPred, Darwin$NP)

#For Cl
Darwin_ClRFPred<-predict(RFModelCl, newdata = Darwin)
cor.test(Darwin_ClRFPred, Darwin$Cl)
plot(Darwin_ClRFPred, Darwin$Cl)
sma(Darwin_ClRFPred~ Darwin$Cl, slope.test=1)
mae(Darwin_ClRFPred, Darwin$Cl)
rmse(Darwin_ClRFPred, Darwin$Cl)

#For NO3
Darwin_NO3RFPred<-predict(RFModelNO3, newdata = Darwin)
cor.test(Darwin_NO3RFPred, Darwin$NO3)
plot(Darwin_NO3RFPred, Darwin$NO3)
sma(Darwin_NO3RFPred~ Darwin$NO3, slope.test=1)
mae(Darwin_NO3RFPred, Darwin$NO3)
rmse(Darwin_NO3RFPred, Darwin$NO3)

#For Ca
Darwin_CaRFPred<-predict(RFModelCa, newdata = Darwin)
cor.test(Darwin_CaRFPred, Darwin$Ca)
plot(Darwin_CaRFPred, Darwin$Ca)
sma(Darwin_CaRFPred~ Darwin$Ca, slope.test=1)
mae(Darwin_CaRFPred, Darwin$Ca)
rmse(Darwin_CaRFPred, Darwin$Ca)

#For Mg
Darwin_MgRFPred<-predict(RFModelMg, newdata = Darwin)
cor.test(Darwin_MgRFPred, Darwin$Mg)
plot(Darwin_MgRFPred, Darwin$Mg)
sma(Darwin_MgRFPred~ Darwin$Mg, slope.test=1)
mae(Darwin_MgRFPred, Darwin$Mg)
rmse(Darwin_MgRFPred, Darwin$Mg)

#For Na
Darwin_NaRFPred<-predict(RFModelNa, newdata = Darwin)
cor.test(Darwin_NaRFPred, Darwin$Na)
plot(Darwin_NaRFPred, Darwin$Na)
sma(Darwin_NaRFPred~ Darwin$Na, slope.test=1)
mae(Darwin_NaRFPred, Darwin$Na)
rmse(Darwin_NaRFPred, Darwin$Na)

#For K
Darwin_KRFPred<-predict(RFModelK, newdata = Darwin)
cor.test(Darwin_KRFPred, Darwin$K)
plot(Darwin_KRFPred, Darwin$K)
sma(Darwin_KRFPred~ Darwin$K, slope.test=1)
mae(Darwin_KRFPred, Darwin$K)
rmse(Darwin_KRFPred, Darwin$K)

###########################################################################################################################

#Exporting Shackleton and Darwin Glacier region RF test results
Shackleton_RFtest_results<- data.frame(TaRFPred, NPRFPred, ClO4RFPred, ClRFPred, FRFPred, NO3RFPred, SO4RFPred,
                                       PO4RFPred, CaRFPred, MgRFPred, NaRFPred, KRFPred, SrRFPred, NH3RFPred)
write.csv(Shackleton_RFtest_results, file = "Shackleton_RFtest_results")


Darwin_RFtest_results <- data.frame(Darwin_TSRFPred,Darwin_NPRFPred,Darwin_ClRFPred,Darwin_NO3RFPred,
                                    Darwin_CaRFPred, Darwin_MgRFPred,Darwin_NaRFPred,Darwin_KRFPred)
write.csv(Darwin_RFtest_results, file = "Darwin_RF_test_results.csv")
